@@ -4,13 +4,13 @@ context("plot_signposts")
 key <- "rkfDr76z75benY3pytM1"
 
 # Plot data from a single identifier gives a bar chart
-dat <- signposts(doi="10.1371/journal.pone.0029797", key=key)
+dat <- alm_signposts(doi="10.1371/journal.pone.0029797", key=key)
 p <- suppressMessages(plot_signposts(input=dat))
 
 # Plot data from many identifiers gives a line chart
 dois <- c('10.1371/journal.pone.0001543','10.1371/journal.pone.0040117',
           '10.1371/journal.pone.0029797','10.1371/journal.pone.0039395')
-dat <- signposts(doi=dois, key=key)
+dat <- alm_signposts(doi=dois, key=key)
 q <- suppressMessages(plot_signposts(input=dat))
 
 test_that("plot_signposts returns the correct class", {
@@ -27,4 +27,4 @@ test_that("plot_signposts returns the correct class", {
 test_that("plot_signposts returns the correct dimensions", {
   expect_that(nrow(p$data), equals(4))
   expect_that(nrow(q$data), equals(16))
-})
\ No newline at end of file
+})
